# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-09-04 03:14
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('address', models.CharField(help_text="user's address", max_length=256)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Time at which the profile was created')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Time at which the profile was updated')),
                ('user', models.OneToOneField(help_text='User for whom the profile is associated', on_delete=django.db.models.deletion.CASCADE, related_name='profile', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='RSVP',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_names', models.CharField(help_text='Comma-separated last names of the people the RSVP is intended for', max_length=256)),
                ('invite_address', models.CharField(help_text='Address invitation was sent to', max_length=256)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Time at which the profile was created')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Time at which the profile was updated')),
                ('profile', models.OneToOneField(help_text='Profile with which the RSVP is associated', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='rsvp', to='wedsite.Profile')),
            ],
        ),
        migrations.CreateModel(
            name='RSVPPerson',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text="RSVP Person's name", max_length=128)),
                ('is_attending_rehearsal', models.NullBooleanField(default=None, help_text='RSVP Status for Friday Night CNY/Shabbat Dinner')),
                ('is_attending_wedding', models.NullBooleanField(default=None, help_text='RSVP Status for Sunday Wedding Ceremony & Reception')),
                ('is_child', models.NullBooleanField(default=None, help_text='TRUE if person is a child')),
                ('dietary_kosher', models.BooleanField(default=False, help_text='Kosher Dietary Restriction')),
                ('dietary_vegetarian', models.BooleanField(default=False, help_text='Vegetarian Dietary Restriction')),
                ('dietary_vegan', models.BooleanField(default=False, help_text='Vegan Dietary Restriction')),
                ('dietary_gluten_free', models.BooleanField(default=False, help_text='Gluten-Free Dietary Restriction')),
                ('dietary_other', models.CharField(blank=True, help_text='Other Dietary Restrictions', max_length=256)),
                ('special_requests', models.CharField(blank=True, help_text='Any other special requests for the person', max_length=256)),
                ('table', models.IntegerField(default=0, help_text='Seating assignment for the guest')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Time at which the profile was created')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Time at which the profile was updated')),
                ('rsvp', models.ForeignKey(help_text='Link back to overall RSVP', on_delete=django.db.models.deletion.CASCADE, related_name='rsvp_person', to='wedsite.RSVP')),
            ],
        ),
    ]
