# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-11-16 02:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wedsite', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='rsvp',
            name='comment',
            field=models.TextField(default='', help_text='RSVP Comment'),
            preserve_default=False,
        ),
    ]
