{% extends "wedding/blocks/base.html" %}

{% block title %}
{{ title }}
{% endblock %}

{% block content %}

{% if validlink %}

<div id="login" class="container-fluid text-center page-container">
    <h1 class="page-header">Confirm Password Reset</h1>

    <p>Please enter your new password twice so we can verify you typed it in correctly.</p>

    <form method="post">{% csrf_token %}
    <fieldset class="module aligned">
        <div class="form-row field-password1">
            {{ form.new_password1.errors }}
            <label for="id_new_password1">New password:</label>
            {{ form.new_password1 }}
        </div>
        <div class="form-row field-password2">
            {{ form.new_password2.errors }}
            <label for="id_new_password2">Confirm password:</label>
            {{ form.new_password2 }}
        </div>
        <input type="submit" class="login-button" value="Change my password" />
    </fieldset>
    </form>
</div>

{% else %}

<p>The password reset link was invalid, possibly because it has already been used.  Please request a new password reset.</p>

{% endif %}

{% endblock %}
